@@ -9,7 +9,7 @@ import Data.Char (toUpper, toLower)
 testzip = "Tests/test.zip"
 testfiles = [ "hello/", "hello/world.txt" ]
 lastfile = last testfiles
-lastfilesize = 71 :: Int
+lastfilesize = 71 :: Integer
 
 world_txt = "And God saw everything that he had made,\
             \ and behold, it was very good.\n"
